@@ -7,14 +7,9 @@
 # Company: QConnex GmbH / Klyqa
 # Author: Frederick Stallmeyer
 #
-# E-Mail: frederick.stallmeyer@gmx.de
 #
 ###################################################################
 
-__version__ = "1.0.17"
-__author__ = "Frederick Stallmeyer <fraizy@gmx.de>"
-__license__ = "MIT"
-
-from .klyqa_ctl import *
-from .general import *
-from .devices.device import format_uid
+__version__: str = "1.0.18"
+__author__: str = "Frederick Stallmeyer"
+__license__: str = "MIT"
