@@ -1,16 +1,26 @@
 """General parameters"""
 
 from __future__ import annotations
+
 import argparse
 
-from .general import DeviceType
+from klyqa_ctl.general.general import DeviceType
 
 
 def get_description_parser() -> argparse.ArgumentParser:
     """Make an argument parse object."""
 
     parser: argparse.ArgumentParser = argparse.ArgumentParser(
-        description="Interactive klyqa device client (local/cloud). In default the client script tries to send the commands via local connection. Therefore a broadcast on udp port 2222 for discovering the lamps is sent in the local network. When the lamp receives the broadcast it answers via tcp on socket 3333 with a new socket tcp connection. On that tcp connection the commands are sent and the replies are received. "
+        add_help=False,
+        description=(
+            "Interactive klyqa device client (local/cloud). In default the"
+            " client script tries to send the commands via local connection."
+            " Therefore a broadcast on udp port 2222 for discovering the lamps"
+            " is sent in the local network. When the lamp receives the"
+            " broadcast it answers via tcp on socket 3333 with a new socket"
+            " tcp connection. On that tcp connection the commands are sent and"
+            " the replies are received. "
+        ),
     )
 
     return parser
@@ -22,7 +32,26 @@ def add_config_args(parser: argparse.ArgumentParser) -> None:
     Args:
         parser: Parser object
     """
-    parser.add_argument("--myip", nargs=1, help="specify own IP for broadcast sender")
+    parser.add_argument(
+        "--myip", nargs=1, help="specify own IP for broadcast sender"
+    )
+
+    parser.add_argument(
+        "--interface",
+        nargs=1,
+        help=(
+            "Set the name of the network interface to send broadcasts"
+            " on for the connection initiating to the devices."
+        ),
+    )
+
+    parser.add_argument(
+        "--passive",
+        help="vApp will passively listen vor UDP SYN from devices",
+        action="store_const",
+        const=True,
+        default=False,
+    )
 
     # parser.add_argument(
     #     "--rerun",
@@ -33,13 +62,21 @@ def add_config_args(parser: argparse.ArgumentParser) -> None:
     # )
 
     parser.add_argument(
-        "--passive",
-        help="vApp will passively listen vor UDP SYN from devices",
+        "--help",
+        help="Show this help.",
         action="store_const",
         const=True,
         default=False,
     )
-    parser.add_argument("--aes", nargs=1, help="give aes key for the lamp")
+
+    parser.add_argument(
+        "--quiet",
+        help="Try to keep the logger to only critical messages.",
+        action="store_const",
+        const=True,
+        default=False,
+    )
+    parser.add_argument("--aes", nargs=1, help="give aes key for the device")
     parser.add_argument("--username", nargs=1, help="give your username")
     parser.add_argument("--password", nargs=1, help="give your klyqa password")
     parser.add_argument(
@@ -57,19 +94,25 @@ def add_config_args(parser: argparse.ArgumentParser) -> None:
     parser.add_argument(
         "--device_name",
         nargs=1,
-        help="give the name of the device from your account settings for the command to send to",
+        help=(
+            "give the name of the device from your account settings for the"
+            " command to send to"
+        ),
     )
     parser.add_argument(
         "--device_unitids",
         nargs=1,
-        help="give the device unit id from your account settings for the command to send to",
+        help=(
+            "give the device unit id from your account settings for the"
+            " command to send to"
+        ),
     )
 
     required = parser.add_argument_group("required arguments")
-    optional = parser.add_argument_group("optional arguments")
+    # optional = parser.add_argument_group("optional arguments")
     required.add_argument(
         "type",
-        choices=[m.name for m in DeviceType],
+        choices=[m.value for m in DeviceType],
         help="choose device type to control",
     )
 
@@ -94,6 +137,13 @@ def add_config_args(parser: argparse.ArgumentParser) -> None:
         const=True,
         default=False,
     )
+    parser.add_argument(
+        "--trace",
+        help="Enable trace logging messages.",
+        action="store_const",
+        const=True,
+        default=False,
+    )
     parser.add_argument(
         "--selectDevice",
         help="Select device.",
@@ -103,24 +153,16 @@ def add_config_args(parser: argparse.ArgumentParser) -> None:
     )
     parser.add_argument(
         "--force",
-        help="If no configs (profiles) about the device available, send the command anyway (can be dangerous).",
+        help=(
+            "If no configs (profiles) about the device available, send the"
+            " command anyway (can be dangerous)."
+        ),
         action="store_const",
         const=True,
         default=False,
     )
     parser.add_argument(
-        "--test",
-        help="Test host server.",
-        action="store_const",
-        const=True,
-        default=False,
-    )
-    parser.add_argument(
-        "--prod",
-        help="Production host server.",
-        action="store_const",
-        const=True,
-        default=True,
+        "--host", help="Set cloud backend host server.", nargs=1
     )
     parser.add_argument(
         "--local",
@@ -129,6 +171,16 @@ def add_config_args(parser: argparse.ArgumentParser) -> None:
         const=True,
         default=False,
     )
+    parser.add_argument(
+        "--offline",
+        help=(
+            "Use cached account settings and device configs, don't connect to"
+            " the cloud backend."
+        ),
+        action="store_const",
+        const=True,
+        default=False,
+    )
     parser.add_argument(
         "--cloud",
         help="Cloud connection to the devices only.",
@@ -138,7 +190,10 @@ def add_config_args(parser: argparse.ArgumentParser) -> None:
     )
     parser.add_argument(
         "--tryLocalThanCloud",
-        help="Try local if fails then cloud connection to the devices. [This is default behaviour]",
+        help=(
+            "Try local if fails then cloud connection to the devices. [This is"
+            " default behaviour]"
+        ),
         action="store_const",
         const=True,
         default=True,
